==> nextcloud-20.0.8p0.tgz: nextcloud/apps/settings/l10n/ast.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migración en cursu. Espera fasta que la migración fine, por favor.",
    "Migration started …" : "Migración aniciada...",
    "Saved" : "Guardóse",
    "Not saved" : "Nun se guardó",
    "Sending…" : "Unviando...",
    "Email sent" : "Corréu-e unviáu",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando...",
    "Unable to change password" : "Nun pue camudase la contraseña",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Select a profile picture" : "Esbillar una imaxe de perfil",
    "Groups" : "Grupos",
    "{actor} changed your password" : "{actor} camudó la to contraseña",
    "You changed your password" : "Camudesti la to contraseña",
    "Your password was reset by an administrator" : "La to contraseña reafitóla un alministrador",
    "{actor} changed your email address" : "{actor} camudó la to direición de corréu",
    "You changed your email address" : "Camudesti la to direición de corréu",
    "Your email address was changed by an administrator" : "La to direición de corréu camudóla un alministrador",
    "Security" : "Seguranza",
    "You successfully logged in using two-factor authentication (%1$s)" : "Aniciesti sesión con ésitu usando l'autenticación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Falló un intentu d'aniciu de sesión usando l'autenticación en dos pasos (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Modificóse la to <strong>contraseña</strong> o <strong>corréu</strong>",
    "Couldn't remove app." : "Nun pudo desaniciase l'aplicación.",
    "Couldn't update app." : "Nun pudo anovase l'aplicación.",
    "Wrong password" : "Contraseña incorreuta",
    "No user supplied" : "Nun s'apurrieron usuarios",
    "Authentication error" : "Fallu d'autenticación",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Apurri una contraseña de recuperación d'alministrador, d'otramiente perderánse tolos datos d'usuariu.",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación d'alministrador incorreuta. Comprueba la contraseña y volvi tentalo.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "El backend nun sofita'l cambéu de contraseña pero anovóse la clave del cifráu d'usuarios",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando y anovando aplicaciones pela tienda d'aplicaciones o compartición de ñube federada",
    "Federated Cloud Sharing" : "Compartición de ñube federada",
    "Invalid SMTP password." : "Contraseña SMTP non válida",
    "Well done, %s!" : "¡Bien fecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si recibes esti corréu, entós la configuración de corréu paez tar bien.",
    "Email could not be sent. Check your mail server log" : "Nun pudo unviase'l corréu. Comprueba'l rexistru del to sirvidor de corréu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Asocedió un problema entrín s'unviaba'l corréu. Revisa los tos axustes por favor. (Fallu: %s)",
    "You need to set your user email before being able to send test emails." : "Tienes de configurar la direición de corréu-e enantes de poder unviar mensaxes de prueba.",
    "Invalid mail address" : "Direición non válida de corréu",
    "Settings saved" : "Axustes guardaos",
    "Unable to change full name" : "Nun pue camudase'l nome completu",
    "Unable to change email address" : "Nun pue camudase la direición de corréu",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pa verificar la to cuenta de Twitter, espubliza elllí'l tuit de darré (por favor asegúrate que lu espublices ensin saltos de llinia):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pa verificar el to sitiu web, atroxa'l conteníu de darréu dientro'l raigañu'l sitiu en «.well-known/CloudIdVerificationCode.txt» (asegúrate que'l testu completu ta nuna llinia):",
    "%1$s changed your password on %2$s." : "%1$s camudó la to contraseña en %2$s.",
    "Your password on %s was changed." : "Camudóse la to contraseña en %s",
    "Your password on %s was reset by an administrator." : "Un alministrador reanició la to contraseña en %s",
    "Password for %1$s changed on %2$s" : "La contraseña pa %1$s camudó en %2$s",
    "Password changed for %s" : "Camudóse la contraseña de %s",
    "If you did not request this, please contact an administrator." : "Si nun solicitesti esto, por favor contautu con un alministrador.",
    "Your email address on %s was changed." : "Camudóse la to direición de corréu en %s",
    "Your email address on %s was changed by an administrator." : "Un alministrador camudó la to direción de corréu en %s",
    "The new email address is %s" : "La nueva direición de corréu ye %s",
    "Your %s account was created" : "Creóse la to cuenta %s",
    "Welcome aboard" : "Afáyate en barcu",
    "Welcome aboard %s" : "Afáyate en barcu %s",
    "Your username is: %s" : "El to nome d'usuariu ye: %s",
    "Set your password" : "Afita la to contraseña",
    "Go to %s" : "Dir a %s",
    "Install Client" : "Instalar veceru",
    "Apps" : "Aplicaciones",
    "Settings" : "Settings",
    "Personal" : "Personal",
    "Additional settings" : "Axustes adicionales",
    "Basic settings" : "Axustes básicos",
    "Sharing" : "Compartiendo",
    "Personal info" : "Información personal",
    "Create" : "Crear",
    "Change" : "Camudar",
    "Delete" : "Desaniciar",
    "Unlimited" : "Non llendáu",
    "Verifying" : "Verificando",
    "Limit to groups" : "Llendar a grupos",
    "Save changes" : "Guardar camudancies",
    "All" : "Toos",
    "No results" : "Ensin resultaos",
    "Remove" : "Desaniciar",
    "Disable" : "Desactivar",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Nun pue instalase esta aplicación porque nun se cumplen les dependencies de darréu:",
    "View in store" : "Ver na tienda",
    "Visit website" : "Visitar sitiu web",
    "Report a bug" : "Informar un fallu",
    "User documentation" : "Documentación d'usuariu",
    "Developer documentation" : "Documentación de desendolcaores",
    "Featured" : "Destacao",
    "No apps found for your version" : "Nun s'alcontraron anovamientos pa la to versión",
    "Enable all" : "Habilitar too",
    "Allow filesystem access" : "Permitir accesu al sistema de ficheros",
    "Rename" : "Renomar",
    "Revoke" : "Revocar",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome p'Android",
    "This session" : "Esta sesión",
    "Device" : "Preséu",
    "Last activity" : "Actividá cabera",
    "Web, desktop and mobile clients currently logged in to your account." : "Veceros web, d'escritoriu y móviles cola sesión aniciada anguaño na to cuenta.",
    "Error while creating device token" : "Fallu entrín se creaba'l pase'l preséu",
    "Error while deleting the token" : "Fallu entrín se desaniciaba'l pase",
    "App name" : "Nome d'aplicación",
    "For security reasons this password will only be shown once." : "Por razones de seguranza, esta contraseña namái s'amosará una vegada.",
    "Username" : "Nome d'usuariu",
    "Password" : "Contraseña",
    "Done" : "Fecho",
    "Copied!" : "¡Copióse!",
    "Copy" : "Copiar",
    "Cancel" : "Encaboxar",
    "{size} used" : "{size} usaos",
    "Display name" : "Nome",
    "Email" : "Corréu-e",
    "Close" : "Zarrar",
    "Quota" : "Cuota",
    "Language" : "Llingua",
    "User backend" : "Backend d'usuarios",
    "Storage location" : "Allugamientu d'almacenamientu",
    "Last login" : "Aniciu de sesión caberu",
    "Default quota" : "Cuota por defeutu",
    "All languages" : "Toles llingües",
    "Add" : "Amestar",
    "Unnamed device" : "Preséu ensin nomar",
    "Your apps" : "Les tos aplicaciones",
    "Disabled apps" : "Aplicaciones deshabilitaes",
    "Updates" : "Anovamientos",
    "App bundles" : "Llotes d'aplicaciones",
    "Details" : "Detalles",
    "Changelog" : "Rexistru de cambeos",
    "Add group" : "Amestar grupu",
    "Everyone" : "Toos",
    "Admins" : "Almins",
    "Show last login" : "Amosar aniciu de sesión caberu",
    "Show user backend" : "Amosar backend d'usuarios",
    "Send email to new user" : "Unviar corréu al usuariu nuevu",
    "Enable" : "Activar",
    "The app will be downloaded from the app store" : "L'aplicación baxaráse dende la tienda d'aplicaciones",
    "Never" : "Enxamás",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Habilitóse l'aplicación pero precisa anovase. Redirixirásete a la páxina d'anovamientu en 5 segundos.",
    "App update" : "Paquetes d'aplicaciones",
    "Error: This app can not be enabled because it makes the server unstable" : "Fallu: Esta aplicación nun pue activase porque fai inestable'l sirvidor",
    "Administrator documentation" : "Documentación d'alministrador",
    "Documentation" : "Documentación",
    "Forum" : "Foru",
    "None" : "Dengún",
    "Login" : "Entamar sesión",
    "Plain" : "Planu",
    "NT LAN Manager" : "Xestor de NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Sirvidor de corréu",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Nun ye importante configurar esti sirvidor pa que seya a unviar correos, como pa refitaminetos de contraseñes y avisos.",
    "Send mode" : "Mou d'unviu",
    "Encryption" : "Cifráu",
    "From address" : "Dende la direición",
    "mail" : "corréu",
    "Authentication method" : "Métodu d'autenticación",
    "Authentication required" : "Necesítase autenticación",
    "Server address" : "Direición del sirvidor",
    "Port" : "Puertu",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nome d'usuariu SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Test email settings" : "Probar configuración de corréu electrónicu",
    "Send email" : "Unviar mensaxe",
    "Security & setup warnings" : "Alvertancies de seguranza y configuración",
    "All checks passed." : "Pasáronse toles comprobaciones.",
    "Version" : "Versión",
    "Server-side encryption" : "Cifráu del llau del sirvidor",
    "Enable server-side encryption" : "Activar cifráu nel sirvidor",
    "Please read carefully before activating server-side encryption: " : "Llei con procuru enantes d'activar el cifráu nel sirvidor:",
    "Be aware that encryption always increases the file size." : "Decátate que'l cifráu siempres aumenta'l tamañu de los ficheros.",
    "This is the final warning: Do you really want to enable encryption?" : "Esta ye l'alvertencia final: ¿De xuru que quies activar el cifráu?",
    "Enable encryption" : "Habilitar cifráu",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nun se cargó dengún módulu de cifráu, activa un módulu de cifráu nel menú d'aplicaciones.",
    "Select default encryption module:" : "Esbilla'l módulu predetermináu de cifráu:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Precises migrar les claves de cifráu d'un cifráu vieyu (ownCloud <= 8.0) a unu nuevu.",
    "Start migration" : "Aniciar migración",
    "Background jobs" : "Trabayos de fondu",
    "Background job didn’t run yet!" : "¡Entá nun s'executó'l trabayu de fondu!",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php precisa executalu l'usuariu del sistema «%s».",
    "Allow apps to use the Share API" : "Permitir a les aplicaciones usar la API de Compartición",
    "Expire after " : "Caduca dempués de",
    "days" : "díes",
    "Enforce expiration date" : "Facer cumplir la data de caducidá",
    "Allow users to share via link" : "Permitir a los usuarios compartir vía enllaz",
    "Allow public uploads" : "Permitir xubes públiques",
    "Always ask for a password" : "Pidir siempres la contraseña",
    "Enforce password protection" : "Ameyora la proteición por contraseña.",
    "Allow resharing" : "Permitir re-compartición",
    "Allow sharing with groups" : "Permiri compartición con grupos",
    "Restrict users to only share with users in their groups" : "Restrinxir a los usuarios a compartir namái con otros usuarios nos sos grupos",
    "Exclude groups from sharing" : "Esclúi grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos van poder siguir recibiendo conteníos compartíos, pero nun van poder anicialos",
    "Like our Facebook page" : "Da-y préstame a la nuesa páxina de Facebook",
    "Follow us on Twitter" : "Síguimos en Twitter.",
    "Check out our blog" : "Comprueba'l nuesu blogue",
    "Subscribe to our newsletter" : "Soscríbite al nuesu boletín",
    "Profile picture" : "Semeya de perfil",
    "Upload new" : "Xubir otra",
    "Remove image" : "Desaniciar imaxe",
    "png or jpg, max. 20 MB" : "png o jpg, máximu 20 MB",
    "Picture provided by original account" : "Semeya fornida pola cuenta orixinal",
    "Full name" : "Nome completu",
    "No display name set" : "Nun s'afitó'l nome p'amosar",
    "Your email address" : "Direición de corréu-e",
    "No email address set" : "Nun s'afitó denguna direición de corréu",
    "For password reset and notifications" : "P'avisos y reaniciu de la contraseña",
    "Phone number" : "Númberu de teléfonu",
    "Your phone number" : "El to númberu de teléfonu",
    "Address" : "Direición",
    "Your postal address" : "La to direición postal",
    "Website" : "Sitiu web",
    "Link https://…" : "Enllaz https://…",
    "Twitter" : "Twitter",
    "Help translate" : "Ayúdanos nes traducciones",
    "Current password" : "Contraseña actual",
    "New password" : "Contraseña nueva",
    "Change password" : "Camudar contraseña",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Asocedió un fallu. Xubi un certificáu PEM con codificación ASCII, por favor.",
    "Valid until {date}" : "Válidu fasta {date}",
    "Local" : "Llocal",
    "Only visible to local users" : "Namái visible pa usuarios llocales",
    "Only visible to you" : "Namái visible pa ti",
    "Contacts" : "Contautos",
    "Visible to local users and to trusted servers" : "Visible pa usuarios llocales y sirvidores d'enfotu",
    "by" : "por",
    "Common Name" : "Nome común",
    "Valid until" : "Válidu hasta",
    "Issued By" : "Emitíu por",
    "Valid until %s" : "Válidu hasta'l %s",
    "Import root certificate" : "Importar certificáu raigañu",
    "Execute one task with each page loaded" : "Executar una xera con cada páxina cargada"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.10.tgz: nextcloud/apps/settings/l10n/ast.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migración en cursu. Espera fasta que la migración fine, por favor.",
    "Migration started …" : "Migración aniciada...",
    "Saved" : "Guardóse",
    "Not saved" : "Nun se guardó",
    "Sending…" : "Unviando...",
    "Email sent" : "Corréu-e unviáu",
    "Local" : "Llocal",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando...",
    "Unable to change password" : "Nun pue camudase la contraseña",
    "Very weak password" : "Contraseña mui feble",
    "Weak password" : "Contraseña feble",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña bona",
    "Strong password" : "Contraseña mui bona",
    "Select a profile picture" : "Esbillar una imaxe de perfil",
    "Groups" : "Grupos",
    "{actor} changed your password" : "{actor} camudó la to contraseña",
    "You changed your password" : "Camudesti la to contraseña",
    "Your password was reset by an administrator" : "La to contraseña reafitóla un alministrador",
    "{actor} changed your email address" : "{actor} camudó la to direición de corréu",
    "You changed your email address" : "Camudesti la to direición de corréu",
    "Your email address was changed by an administrator" : "La to direición de corréu camudóla un alministrador",
    "Security" : "Seguranza",
    "You successfully logged in using two-factor authentication (%1$s)" : "Aniciesti sesión con ésitu usando l'autenticación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Falló un intentu d'aniciu de sesión usando l'autenticación en dos pasos (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Modificóse la to <strong>contraseña</strong> o <strong>corréu</strong>",
    "Couldn't remove app." : "Nun pudo desaniciase l'aplicación.",
    "Couldn't update app." : "Nun pudo anovase l'aplicación.",
    "Wrong password" : "Contraseña incorreuta",
    "No user supplied" : "Nun s'apurrieron usuarios",
    "Authentication error" : "Fallu d'autenticación",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Apurri una contraseña de recuperación d'alministrador, d'otramiente perderánse tolos datos d'usuariu.",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación d'alministrador incorreuta. Comprueba la contraseña y volvi tentalo.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "El backend nun sofita'l cambéu de contraseña pero anovóse la clave del cifráu d'usuarios",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalando y anovando aplicaciones pela tienda d'aplicaciones o compartición de ñube federada",
    "Federated Cloud Sharing" : "Compartición de ñube federada",
    "Invalid SMTP password." : "Contraseña SMTP non válida",
    "Well done, %s!" : "¡Bien fecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si recibes esti corréu, entós la configuración de corréu paez tar bien.",
    "Email could not be sent. Check your mail server log" : "Nun pudo unviase'l corréu. Comprueba'l rexistru del to sirvidor de corréu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Asocedió un problema entrín s'unviaba'l corréu. Revisa los tos axustes por favor. (Fallu: %s)",
    "You need to set your user email before being able to send test emails." : "Tienes de configurar la direición de corréu-e enantes de poder unviar mensaxes de prueba.",
    "Invalid mail address" : "Direición non válida de corréu",
    "Settings saved" : "Axustes guardaos",
    "Unable to change full name" : "Nun pue camudase'l nome completu",
    "Unable to change email address" : "Nun pue camudase la direición de corréu",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pa verificar la to cuenta de Twitter, espubliza elllí'l tuit de darré (por favor asegúrate que lu espublices ensin saltos de llinia):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pa verificar el to sitiu web, atroxa'l conteníu de darréu dientro'l raigañu'l sitiu en «.well-known/CloudIdVerificationCode.txt» (asegúrate que'l testu completu ta nuna llinia):",
    "%1$s changed your password on %2$s." : "%1$s camudó la to contraseña en %2$s.",
    "Your password on %s was changed." : "Camudóse la to contraseña en %s",
    "Your password on %s was reset by an administrator." : "Un alministrador reanició la to contraseña en %s",
    "Password for %1$s changed on %2$s" : "La contraseña pa %1$s camudó en %2$s",
    "Password changed for %s" : "Camudóse la contraseña de %s",
    "If you did not request this, please contact an administrator." : "Si nun solicitesti esto, por favor contautu con un alministrador.",
    "Your email address on %s was changed." : "Camudóse la to direición de corréu en %s",
    "Your email address on %s was changed by an administrator." : "Un alministrador camudó la to direción de corréu en %s",
    "The new email address is %s" : "La nueva direición de corréu ye %s",
    "Your %s account was created" : "Creóse la to cuenta %s",
    "Welcome aboard" : "Afáyate en barcu",
    "Welcome aboard %s" : "Afáyate en barcu %s",
    "Your username is: %s" : "El to nome d'usuariu ye: %s",
    "Set your password" : "Afita la to contraseña",
    "Go to %s" : "Dir a %s",
    "Install Client" : "Instalar veceru",
    "Apps" : "Aplicaciones",
    "Settings" : "Settings",
    "Personal" : "Personal",
    "Additional settings" : "Axustes adicionales",
    "Basic settings" : "Axustes básicos",
    "Sharing" : "Compartiendo",
    "Personal info" : "Información personal",
    "Create" : "Crear",
    "Change" : "Camudar",
    "Delete" : "Desaniciar",
    "Unlimited" : "Non llendáu",
    "Verifying" : "Verificando",
    "Limit to groups" : "Llendar a grupos",
    "Save changes" : "Guardar camudancies",
    "All" : "Toos",
    "No results" : "Ensin resultaos",
    "Remove" : "Desaniciar",
    "Disable" : "Desactivar",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Nun pue instalase esta aplicación porque nun se cumplen les dependencies de darréu:",
    "View in store" : "Ver na tienda",
    "Visit website" : "Visitar sitiu web",
    "Report a bug" : "Informar un fallu",
    "User documentation" : "Documentación d'usuariu",
    "Developer documentation" : "Documentación de desendolcaores",
    "Featured" : "Destacao",
    "No apps found for your version" : "Nun s'alcontraron anovamientos pa la to versión",
    "Enable all" : "Habilitar too",
    "Allow filesystem access" : "Permitir accesu al sistema de ficheros",
    "Rename" : "Renomar",
    "Revoke" : "Revocar",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome p'Android",
    "This session" : "Esta sesión",
    "Device" : "Preséu",
    "Last activity" : "Actividá cabera",
    "Web, desktop and mobile clients currently logged in to your account." : "Veceros web, d'escritoriu y móviles cola sesión aniciada anguaño na to cuenta.",
    "Error while creating device token" : "Fallu entrín se creaba'l pase'l preséu",
    "Error while deleting the token" : "Fallu entrín se desaniciaba'l pase",
    "App name" : "Nome d'aplicación",
    "For security reasons this password will only be shown once." : "Por razones de seguranza, esta contraseña namái s'amosará una vegada.",
    "Username" : "Nome d'usuariu",
    "Password" : "Contraseña",
    "Done" : "Fecho",
    "Copied!" : "¡Copióse!",
    "Copy" : "Copiar",
    "Cancel" : "Encaboxar",
    "{size} used" : "{size} usaos",
    "Display name" : "Nome",
    "Email" : "Corréu-e",
    "Quota" : "Cuota",
    "Language" : "Llingua",
    "User backend" : "Backend d'usuarios",
    "Storage location" : "Allugamientu d'almacenamientu",
    "Last login" : "Aniciu de sesión caberu",
    "Default quota" : "Cuota por defeutu",
    "All languages" : "Toles llingües",
    "Add" : "Amestar",
    "Unnamed device" : "Preséu ensin nomar",
    "Your apps" : "Les tos aplicaciones",
    "Disabled apps" : "Aplicaciones deshabilitaes",
    "Updates" : "Anovamientos",
    "App bundles" : "Llotes d'aplicaciones",
    "Details" : "Detalles",
    "Changelog" : "Rexistru de cambeos",
    "Add group" : "Amestar grupu",
    "Everyone" : "Toos",
    "Admins" : "Almins",
    "Show last login" : "Amosar aniciu de sesión caberu",
    "Show user backend" : "Amosar backend d'usuarios",
    "Send email to new user" : "Unviar corréu al usuariu nuevu",
    "Enable" : "Activar",
    "The app will be downloaded from the app store" : "L'aplicación baxaráse dende la tienda d'aplicaciones",
    "Never" : "Enxamás",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Habilitóse l'aplicación pero precisa anovase. Redirixirásete a la páxina d'anovamientu en 5 segundos.",
    "App update" : "Paquetes d'aplicaciones",
    "Error: This app can not be enabled because it makes the server unstable" : "Fallu: Esta aplicación nun pue activase porque fai inestable'l sirvidor",
    "Administrator documentation" : "Documentación d'alministrador",
    "Documentation" : "Documentación",
    "Forum" : "Foru",
    "None" : "Dengún",
    "Login" : "Entamar sesión",
    "Plain" : "Planu",
    "NT LAN Manager" : "Xestor de NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Sirvidor de corréu",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Nun ye importante configurar esti sirvidor pa que seya a unviar correos, como pa refitaminetos de contraseñes y avisos.",
    "Send mode" : "Mou d'unviu",
    "Encryption" : "Cifráu",
    "From address" : "Dende la direición",
    "mail" : "corréu",
    "Authentication method" : "Métodu d'autenticación",
    "Authentication required" : "Necesítase autenticación",
    "Server address" : "Direición del sirvidor",
    "Port" : "Puertu",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nome d'usuariu SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Test email settings" : "Probar configuración de corréu electrónicu",
    "Send email" : "Unviar mensaxe",
    "Security & setup warnings" : "Alvertancies de seguranza y configuración",
    "All checks passed." : "Pasáronse toles comprobaciones.",
    "Version" : "Versión",
    "Server-side encryption" : "Cifráu del llau del sirvidor",
    "Enable server-side encryption" : "Activar cifráu nel sirvidor",
    "Please read carefully before activating server-side encryption: " : "Llei con procuru enantes d'activar el cifráu nel sirvidor:",
    "Be aware that encryption always increases the file size." : "Decátate que'l cifráu siempres aumenta'l tamañu de los ficheros.",
    "This is the final warning: Do you really want to enable encryption?" : "Esta ye l'alvertencia final: ¿De xuru que quies activar el cifráu?",
    "Enable encryption" : "Habilitar cifráu",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nun se cargó dengún módulu de cifráu, activa un módulu de cifráu nel menú d'aplicaciones.",
    "Select default encryption module:" : "Esbilla'l módulu predetermináu de cifráu:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Precises migrar les claves de cifráu d'un cifráu vieyu (ownCloud <= 8.0) a unu nuevu.",
    "Start migration" : "Aniciar migración",
    "Background jobs" : "Trabayos de fondu",
    "Background job didn’t run yet!" : "¡Entá nun s'executó'l trabayu de fondu!",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php precisa executalu l'usuariu del sistema «%s».",
    "Allow apps to use the Share API" : "Permitir a les aplicaciones usar la API de Compartición",
    "Expire after " : "Caduca dempués de",
    "days" : "díes",
    "Enforce expiration date" : "Facer cumplir la data de caducidá",
    "Allow public uploads" : "Permitir xubes públiques",
    "Always ask for a password" : "Pidir siempres la contraseña",
    "Enforce password protection" : "Ameyora la proteición por contraseña.",
    "Allow resharing" : "Permitir re-compartición",
    "Allow sharing with groups" : "Permiri compartición con grupos",
    "Restrict users to only share with users in their groups" : "Restrinxir a los usuarios a compartir namái con otros usuarios nos sos grupos",
    "Exclude groups from sharing" : "Esclúi grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos van poder siguir recibiendo conteníos compartíos, pero nun van poder anicialos",
    "Like our Facebook page" : "Da-y préstame a la nuesa páxina de Facebook",
    "Follow us on Twitter" : "Síguimos en Twitter.",
    "Check out our blog" : "Comprueba'l nuesu blogue",
    "Subscribe to our newsletter" : "Soscríbite al nuesu boletín",
    "Profile picture" : "Semeya de perfil",
    "Upload new" : "Xubir otra",
    "Remove image" : "Desaniciar imaxe",
    "png or jpg, max. 20 MB" : "png o jpg, máximu 20 MB",
    "Picture provided by original account" : "Semeya fornida pola cuenta orixinal",
    "Full name" : "Nome completu",
    "No display name set" : "Nun s'afitó'l nome p'amosar",
    "Your email address" : "Direición de corréu-e",
    "No email address set" : "Nun s'afitó denguna direición de corréu",
    "For password reset and notifications" : "P'avisos y reaniciu de la contraseña",
    "Phone number" : "Númberu de teléfonu",
    "Your phone number" : "El to númberu de teléfonu",
    "Address" : "Direición",
    "Your postal address" : "La to direición postal",
    "Website" : "Sitiu web",
    "Link https://…" : "Enllaz https://…",
    "Twitter" : "Twitter",
    "Help translate" : "Ayúdanos nes traducciones",
    "Current password" : "Contraseña actual",
    "New password" : "Contraseña nueva",
    "Change password" : "Camudar contraseña",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Asocedió un fallu. Xubi un certificáu PEM con codificación ASCII, por favor.",
    "Valid until {date}" : "Válidu fasta {date}",
    "Only visible to local users" : "Namái visible pa usuarios llocales",
    "Only visible to you" : "Namái visible pa ti",
    "Contacts" : "Contautos",
    "Visible to local users and to trusted servers" : "Visible pa usuarios llocales y sirvidores d'enfotu",
    "by" : "por",
    "Close" : "Zarrar",
    "Common Name" : "Nome común",
    "Valid until" : "Válidu hasta",
    "Issued By" : "Emitíu por",
    "Valid until %s" : "Válidu hasta'l %s",
    "Import root certificate" : "Importar certificáu raigañu",
    "Execute one task with each page loaded" : "Executar una xera con cada páxina cargada",
    "Allow users to share via link" : "Permitir a los usuarios compartir vía enllaz"
},
"nplurals=2; plural=(n != 1);");
